﻿using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DTO.Common;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.DTO.Organization;
using WingInterfaceLibrary.DTO;
using WingInterfaceLibrary.Request.Consultation;
using WingInterfaceLibrary.Result.Consultation;
using WingInterfaceLibrary.DTO.Consultation;
using WingInterfaceLibrary.DTO.User;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 预约会诊接口
    /// </summary>
    /// <value>预约会诊</value>
    /// <example>预约会诊服务</example>    
    public interface ILiveConsultationService
    {

        /// <summary>
        /// 查询上级机构集合
        /// </summary>
        /// <param name="request">查询上级机构集合请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<List<OrganizationBaseDTO>> FindParentOrganizationsAsync(FindHigherOrganizationsRequest request);

        /// <summary>
        /// 查询基层机构集合
        /// </summary>
        /// <param name="request">查询基层机构集合请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<List<OrganizationBaseDTO>> FindGrassRootsOrganizationsAsync(FindGrassRootsOrganizationsRequest request);

        /// <summary>
        /// 查询机构专家集合
        /// </summary>
        /// <param name="request">查询机构专家集合请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<List<UserDTO>> FindOrganizationExpertsAsync(FindOrganizationExpertsRequest request);

        /// <summary>
        /// 申请会诊
        /// </summary>
        /// <param name="request">申请会诊请求实体</param>
        /// <returns>会诊编码</returns>
        /// <errorCodes></errorCodes>
        Task<string> ApplyConsultationAsync(ApplyConsultationRequest request);

        /// <summary>
        /// 分页查询会诊记录
        /// </summary>
        /// <param name="request">分页查询会诊记录请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<PageResult<ConsultationDetailDTO>> FindConsultationByPageAsync(FindConsultationByPageRequest request);

        /// <summary>
        /// 查询会诊详情
        /// </summary>
        /// <param name="request">查询会诊详情请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<ConsultationDetailDTO> FindConsultationDetailAsync(FindConsultationDetailRequest request);

        /// <summary>
        /// 批准会诊申请
        /// </summary>
        /// <param name="request">批准会诊申请请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<bool> ApprovalConsultationAsync(ApprovalConsultationRequest request);

        /// <summary>
        /// 撤回会诊申请
        /// </summary>
        /// <param name="request">撤回会诊申请请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<bool> RevokeConsultationAsync(RevokeConsultationRequest request);

        /// <summary>
        /// 删除会诊记录
        /// </summary>
        /// <param name="request">删除会诊记录请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<bool> DeleteConsultationAsync(DeleteConsultationRequest request);

        /// <summary>
        /// 保存预约会诊图像
        /// 累加保存
        /// </summary>
        /// <param name="request">保存预约会诊图像请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<bool> UpdateConsultationFilesInfoAsync(UpdateConsultationFilesInfoRequest request);


        /// <summary>
        /// 预约会诊加星
        /// </summary>
        /// <param name="request">预约会诊加星请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<bool> ConsultationAddStarAsync(ConsultationAddStarRequest request);

        /// <summary>
        /// 添加随访记录
        /// </summary>
        /// <param name="request">添加随访记录请求实体</param>
        /// <returns></returns>
        /// <errorCodes></errorCodes>
        Task<bool> AddConsultationFollowUpRecordAsync(AddConsultationFollowUpRecordRequest request);



        /// <summary>
        /// Initiate a diagnosis meeting
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        /// <show>false</show>
        Task<InitiateLiveConsultationResult> InitiateLiveConsultationAsync(InitiateLiveConsultationRequest request);

        /// <summary>
        /// Cancel the initiating a diagnosis meeting
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        /// <show>false</show>
        Task<CancelLiveConsultationResult> CancelLiveConsultationAsync(CancelLiveConsultationRequest request);

        /// <summary>
        /// Accept a diagnosis request
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        /// <show>false</show>
        Task<AcceptLiveConsultationResult> AcceptLiveConsultationAsync(AcceptLiveConsultationRequest request);

        /// <summary>
        /// Reject a diagnosis request
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        Task<RejectLiveConsultationResult> RejectLiveConsultationAsync(RejectLiveConsultationRequest request);
        /// <summary>
        /// Join a diagnosis request
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        /// <show>false</show>
        Task<JoinLiveConsultationResult> JoinLiveConsultationAsync(JoinLiveConsultationRequest request);
        /// <summary>
        /// Leave a diagnosis request
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        /// <show>false</show>
        Task<LeaveLiveConsultationResult> LeaveLiveConsultationAsync(LeaveLiveConsultationRequest request);
        /// <summary>
        /// 设置开启或关闭静音状态
        /// </summary>
        /// <param name="request">设置开启或关闭静音状态的请求</param>
        /// <returns></returns>
        /// <show>false</show>
        Task<MuteLiveConsultationResult> MuteLiveConsultationAsync(MuteLiveConsultationRequest request);
        /// <summary>
        /// 开启或关闭视频
        /// </summary>
        /// <param name="request">开启或关闭视频请求</param>
        /// <returns></returns>
        /// <show>false</show>
        
        Task<SwitchLiveConsultationVideoResult> SwitchLiveConsultationVideoAsync(SwitchLiveConsultationVideoRequest request);
        /// <summary>
        /// Send HeartRate request in a diagnosis metting
        /// </summary>
        /// <param name="request">The request</param>
        /// <returns></returns>
        /// <show>false</show>
        
        Task<LiveConsultationHeartRateResult> HeartRateAsync(LiveConsultationHeartRateRequest request);

        /// <summary>
        /// 发送互动白板操作数据
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> SendInteractiveBoardDataAsync(SendInteractiveBoardDataRequest request);
    }
}